Encrypter class

Wraps Algorithms in a unique Container.

Constructors

Encrypter(Algorithm algo)

Properties

algo → Algorithm
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decrypt(Encrypted encrypted, {IV? iv, Uint8List? associatedData}) → String
Calls decrypt on the wrapped Algorithm.
decrypt16(String encoded, {IV? iv, Uint8List? associatedData}) → String
Sugar for decrypt(Encrypted.fromBase16(encoded)).
decrypt64(String encoded, {IV? iv, Uint8List? associatedData}) → String
Sugar for decrypt(Encrypted.fromBase64(encoded)).
decryptBytes(Encrypted encrypted, {IV? iv, Uint8List? associatedData}) → List<int>
Calls decrypt on the wrapped Algorith without UTF-8 decoding.
encrypt(String input, {IV? iv, Uint8List? associatedData}) → Encrypted
Calls encrypt on the wrapped Algorithm.
encryptBytes(List<int> input, {IV? iv, Uint8List? associatedData}) → Encrypted
Calls encrypt on the wrapped Algorithm using a raw binary.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited