Fernet class

Wraps the Fernet Algorithm.

Implemented types

Constructors

Fernet(Key key, {Clock? clock})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decrypt(Encrypted encrypted, {IV? iv, Uint8List? associatedData, int? ttl}) → Uint8List
Decrypt encrypted value.
override
encrypt(Uint8List bytes, {IV? iv, Uint8List? associatedData}) → Encrypted
Encrypt bytes.
override
extractTimestamp(Uint8List data) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited