Signer class

Constructors

Signer(SignerAlgorithm algo)

Properties

algo → SignerAlgorithm
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign(String input) → Encrypted
signBytes(List<int> bytes) → Encrypted
toString() → String
A string representation of this object.
inherited
verify(String input, Encrypted signature) → bool
verify16(String input, String signature) → bool
verify64(String input, String signature) → bool
verifyBytes(List<int> bytes, Encrypted signature) → bool

Operators

operator ==(Object other) → bool
The equality operator.
inherited