EasyCoder class

Json序列化的数据模型的生成器、虚拟机桥接类型的生成器

Inheritance

Constructors

EasyCoder({required EasyCoderConfig config})

Properties

hashCode int
The hash code for this object.
no setterinherited
logTag String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateModel(EasyCoderModelInfo modelInfo, {List<String> headerComments = const []}) → void
生成数据库模型
generateModelExports({String outputFile = 'all.dart'}) → void
生成基本模型导出文件
logDebug(List args) → void
inherited
logError(List args) → void
inherited
logFatal(List args) → void
inherited
logInfo(List args) → void
inherited
logTrace(List args) → void
inherited
logWarn(List args) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

firstUpperCaseName(String name) String
name的第一个字母改为大写